
//! Currently includes human NCBI gencode GRCh38. Automatically downloads the latest version of user's choice.

pub mod ftp;
pub mod ercc;
pub mod phix;